# ``| -> YvesCMD <- |``

<p align="center">
  <b>pip install yvesCMD</b>
</p>
<p align="center">
  This microframework is created for cmd applications based on the cmd module in Python, which is built-in by default.
</p>

<p align="center">
  <b>Goals</b>
</p>
<p align="center">
  The goal is to provide simple and useful tools for creating shell applications. Automate certain processes and introduce innovations in this area.
</p>

<p align="center">
  <b>What's New</b>
</p>
<p align="center">
  - do_command -> In the original module, all command options were placed in the first or first after self argument. In this version, each option occupies its place in the arguments, which provides more control over how many and what the user will enter.<br>
  - void_command -> Completely without arguments, a dummy function that you call without options.<br>
  - relative_prompt -> For some reason, in the original module, changing the prompt during code execution is impossible.
</p>

<p align="center">
  <a href="https://github.com/Yveradvir/Yvescmd/tree/master/YvesCMD/src/extensions"><b>Extensions</b></a>
</p>

<p align="center">
  This is a directory in the repository where various features will be introduced.
</p>

<p align="center">
  <a href="https://github.com/Yveradvir/Yvescmd"><b>GitHub</b></a> | <a href="https://pypi.org/project/yvesCMD/"><b>PyPi</b></a>
</p>